@@ -147,15 +147,15 @@ class LRFind(Config):
         return v
 
     def make(self, optimizer, **kwargs):
-        argument = override(kwargs,
-                            lr_min=self.lr_min
-                            lr_max=self.lr_max,
-                            n_iter=self.n_iter
-                            linear=self.linear)
-        
-        return lr_scheduler.lr_finder(
-            optimizer, **argument
+        argument = override(
+            kwargs,
+            lr_min=self.lr_min,
+            lr_max=self.lr_max,
+            n_iter=self.n_iter,
+            linear=self.linear,
         )
 
+        return lr_scheduler.lr_finder(optimizer, **argument)
+
 
 Scheduler = Union[Constant, Cycle, Step, ExpEpoch, Exp, LRFind]
